pub struct HarnessUsageConfig {
pub content: HarnessUsageContentConfig,
pub harnesses: BTreeMap<HarnessId, HarnessConfig>,
}Expand description
Harness usage hook behavior configuration.
Fields
content: HarnessUsageContentConfigDefault content policy for all configured Harnesses.
harnesses: BTreeMap<HarnessId, HarnessConfig>Built-in enablement overrides and custom Harness definitions.
Implementations
Sourceimpl HarnessUsageConfig
impl HarnessUsageConfig
Sourcepub fn enabled_for_harness(&self, harness_id: &str) -> bool
pub fn enabled_for_harness(&self, harness_id: &str) -> bool
Returns whether usage events are enabled for one Harness.
Sourcepub fn content_for_harness(&self, harness_id: &str) -> HarnessUsageContentConfig
pub fn content_for_harness(&self, harness_id: &str) -> HarnessUsageContentConfig
Returns the effective independent content policy for one Harness.