pub struct HooksRuntimeConfig { /* private fields */ }Expand description
Shared dynamic hooks configuration.
Implementations
Sourceimpl HooksRuntimeConfig
impl HooksRuntimeConfig
Sourcepub fn new(config: HooksConfig) -> Self
pub fn new(config: HooksConfig) -> Self
Creates a dynamic hook config handle with the supplied initial snapshot.
Sourcepub fn default_enabled() -> Self
pub fn default_enabled() -> Self
Creates a dynamic hook config handle with built-in defaults.
Sourcepub fn snapshot(&self) -> Arc<HooksConfig> ⓘ
pub fn snapshot(&self) -> Arc<HooksConfig> ⓘ
Returns the current hooks configuration snapshot.
Sourcepub fn update(&self, config: HooksConfig) -> HooksConfig
pub fn update(&self, config: HooksConfig) -> HooksConfig
Atomically replaces the hooks configuration for future hook invocations.