pub struct HarnessUsageHook<S>where
S: AgentEventSink,{ /* private fields */ }Expand description
Broker Hook that owns the complete Harness usage pipeline.
Implementations
Sourceimpl<S> HarnessUsageHook<S>where
S: AgentEventSink,
impl<S> HarnessUsageHook<S>where
S: AgentEventSink,
Sourcepub fn with_runtime_config_and_event_sink(
config: HarnessUsageHookConfig,
runtime_config: HooksRuntimeConfig,
sink: S,
) -> Self
pub fn with_runtime_config_and_event_sink( config: HarnessUsageHookConfig, runtime_config: HooksRuntimeConfig, sink: S, ) -> Self
Creates the unified pipeline with shared policy and event delivery.